function addFootSpringMarkersToModel(varargin)
% Adds Markers to model based on the spring locations in order to visualize
% spring placement on the foot in the OpenSim GUI.


%import OpenSim Matlab API functions
import org.opensim.modeling.*
import java.lang.*

% inModel = 'NS_jointOpt_withStaticMarkers_changedMarkers.osim'
inModel = 'Subject1_jointOpt_v4pt1_withStatic.osim'
outModel='ModelWithSprings.osim';

load SpringLocsL.mat
SpringsHL = SpringsH;
SpringsTL = SpringsT;
load SpringLocsR.mat
SpringsHR = SpringsH;
SpringsTR = SpringsT;

%setup OpenSim model
model=Model(inModel);

for iii = 1:42
    body = model.getBodySet.get(iii);
    if strcmp(body,'calcn_l_markerPlate')
        calcn_l_index = iii;
    end
    if strcmp(body,'toes_l_markerPlate')
        toes_l_index = iii;
    end
    if strcmp(body,'calcn_r_markerPlate')
        calcn_r_index = iii;
    end
    if strcmp(body,'toes_r_markerPlate')
        toes_r_index = iii;
    end
end

Body = model.getBodySet.get(calcn_l_index);
for i = 1:size(SpringsHL,1)
    Name = String(['Left Heel Marker' num2str(i)]);
    marker=model.getMarkerSet.addMarker(Name, SpringsHL(i,:), Body);
end

Body = model.getBodySet.get(toes_l_index);
for i = 1:size(SpringsTL,1)
    Name = String(['Left Toe Marker' num2str(i)]);
    marker=model.getMarkerSet.addMarker(Name, SpringsTL(i,:), Body);
end

Body = model.getBodySet.get(calcn_r_index);
for i = 1:size(SpringsHR,1)
    Name = String(['Right Heel Marker' num2str(i)]);
    marker=model.getMarkerSet.addMarker(Name, SpringsHR(i,:), Body);
end

Body = model.getBodySet.get(toes_r_index);
for i = 1:size(SpringsTR,1)
    Name = String(['Right Toe Marker' num2str(i)]);
    marker=model.getMarkerSet.addMarker(Name, SpringsTR(i,:), Body);
end

%output, i.e., plate, .osim model
model.setName(outModel);%set name
model.print(outModel);%print